@@ -111,4 +111,30 @@ class PopplerFormFieldChoice : public Okular::FormFieldChoice
 
 };
 
+class PopplerSignatureInfo;
+class PopplerFormFieldSignature : public Okular::FormFieldSignature
+{
+    public:
+        PopplerFormFieldSignature( Poppler::FormFieldSignature * field );
+        virtual ~PopplerFormFieldSignature();
+
+        // inherited from Okular::FormField
+        Okular::NormalizedRect rect() const override;
+        int id() const override;
+        QString name() const override;
+        QString uiName() const override;
+        bool isReadOnly() const override;
+        bool isVisible() const override;
+
+        // inherited from Okular::FormFieldSignature
+        SignatureType signatureType() const override;
+        const Okular::SignatureInfo &signatureInfo() const override;
+
+    private:
+        Poppler::FormFieldSignature * m_field;
+        Okular::SignatureInfo *m_info;
+        Okular::NormalizedRect m_rect;
+        int m_id;
+};
+
 #endif
