@@ -10,9 +10,9 @@
 #ifndef _OKULAR_PAGEPAINTER_H_
 #define _OKULAR_PAGEPAINTER_H_
 
-#include <QtGui/QBrush>
-#include <QtGui/QImage>
-#include <QtGui/QPen>
+#include <QBrush>
+#include <QImage>
+#include <QPen>
 
 #include "core/area.h"  // for NormalizedPoint
 
